# Revision Graph: Glossary

## Introduction

This glossary establishes standard terminology for the Revision Graph module. Consistent terminology improves the user experience, reduces confusion, and provides a framework for developers when refactoring or extending the module. All user interface text should reflect these terms.

## Core Concepts

| Term | Definition | Terms to Avoid |
|------|------------|----------------|
| **Revision** | A single saved state of content that represents a change from a previous state. | "Version", "Commit", "Save point" |
| **Revision Graph** | Visual representation of the relationships between content revisions. | "Version history", "Commit graph" |
| **Node** | (1) A content entity in Drupal. (2) A visual element in the graph representing a single revision. In UI text, prefer "revision circle" over "node" when referring to the visual elements to avoid confusion with Drupal's content nodes. | "Commit circle", "Version bubble" |
| **Branch** | A sequence of revisions that diverges from the main sequence, typically representing a translation or a complex editorial workflow. | "Fork", "Split", "Thread" |
| **Connection** | A line in the graph showing the relationship between revisions. | "Branch line", "Edge", "Link" |
| **Current Revision** | The currently published or active revision of content. Always use this term for the active revision, not "latest" which could be ambiguous. | "Active version", "Latest commit", "Head" |

## Visual Elements

| Term | Definition | Terms to Avoid |
|------|------------|----------------|
| **Revision Circle** | The circular visual element representing a revision in the graph. | "Node", "Dot", "Commit bubble" |
| **Date Marker** | Horizontal line indicating when revisions were created. | "Timeline marker", "Time indicator" |
| **Revision Details** | Information about a specific revision shown when interacting with a revision circle. | "Commit info", "Version data" |
| **Branch Label** | Text label indicating a branch name, typically a language code for translated content. | "Language indicator", "Fork name" |

## Actions

| Term | Definition | Terms to Avoid |
|------|------------|----------------|
| **View Revision** | Action to display a specific revision of content. | "Show version", "Display commit" |
| **Revert to Revision** | Action to make a historical revision the current published content. | "Restore version", "Rollback to commit" |
| **Compare Revisions** | Action to see differences between two revisions. | "Diff versions", "See commit changes" |

## Technical Terms

| Term | Definition | Terms to Avoid |
|------|------------|----------------|
| **Author** | The user who created a specific revision. | "Committer", "Editor", "User" |
| **Timestamp** | The date and time when a revision was created. | "Commit time", "Version date" |
| **Message** | The note associated with a revision explaining the changes made. | "Commit message", "Log entry" |
| **Tag** | A label attached to a specific revision to mark it as significant. | "Version marker", "Commit tag" |

## Historical Context

| Term | Definition | Terms to Avoid |
|------|------------|----------------|
| **Revision History** | The complete sequence of changes made to content over time. | "Version history", "Commit log" |
| **Parent Revision** | The revision from which a current revision was derived. | "Previous version", "Ancestor commit" |
| **Child Revision** | A revision derived from another revision. | "Next version", "Descendant commit" |

## UI Interactions

| Term | Definition | Terms to Avoid |
|------|------------|----------------|
| **Select Revision** | Action of clicking or focusing on a revision circle in the graph. | "Choose commit", "Pick version" |
| **Navigate Graph** | Moving through the revision graph using keyboard or mouse. | "Browse commits", "Travel through versions" |
| **Expand Details** | Action of viewing more information about a selected revision. | "Open commit", "View version info" |


## Mapping from Git Terminology

For developers familiar with Git, this mapping clarifies how Drupal revision terminology relates to Git concepts:

| Git Term | Revision Graph Term | Notes |
|----------|---------------------|-------|
| Commit | Revision | The fundamental unit of change |
| Branch | Branch | Similar concept, though in content context |
| Repository | Content Entity | The container for revisions |
| HEAD | N/A | N/A |
| Merge | N/A | Not directly applicable in standard Drupal |
| Tag | Tag | Similar concept marking significant points |
| Log Message | Revision Message | Description of changes |
| Checkout | N/A | However, one can "view" the revision, which is quite close |
| Revert | Revert to Revision | Returning to a previous state |

---

This glossary will evolve as the module develops. 
Suggestions for terminology improvements should be submitted through the project's [issue queue](https://www.drupal.org/project/issues/revision_graph). 