import { defineConfig, UserConfig } from "vite";
import dts from "vite-plugin-dts";
import { resolve } from "path";

const config: UserConfig = {
  plugins: [
    dts({
      insertTypesEntry: true,
      include: ["src/**/*.ts"],
      rollupTypes: true,
      copyDtsFiles: false,
      outDir: "dist/types",
      tsconfigPath: resolve(__dirname, "./tsconfig.json"),
    }),
  ],
  resolve: {
    alias: {
      "@": resolve(__dirname, "./src"),
    },
  },
  css: {
    modules: false as const,
  },
  build: {
    lib: {
      entry: resolve(__dirname, "src/index.ts"),
      name: "RevisionGraph",
      fileName: (format) => `revision-graph.${format}.js`,
      formats: ["iife"],
    },
    rollupOptions: {
      external: [],
      output: {
        globals: {},
        extend: true,
        intro: "// Revision Graph - Git commit visualization library\n",
        outro: "// End Revision Graph",
        assetFileNames: (assetInfo) => {
          if (assetInfo.name === "style.css") return "revision-graph.css";
          return assetInfo.name || "asset";
        },
      },
    },
    outDir: "../js/revision-graph",
    emptyOutDir: true,
    sourcemap: true,
    minify: "terser",
    terserOptions: {
      compress: {
        drop_console: true,
      },
      format: {
        comments: false,
      },
    },
    target: "es2020",
  },
};

export default defineConfig(config); 